VirtIO queue (virtqueue) implementation.
This module provides the core virtqueue data structures used for communication between the guest driver and host device.
Modules
- flags
- Descriptor flags sourced from
virtio_bindings::virtio_ring.
Structs
- Avail
Ring - Available ring structure.
- Descriptor
- A single descriptor in the descriptor table.
- Descriptor
Chain - Iterator over a descriptor chain.
- Used
Element - Used ring element.
- Used
Ring - Used ring structure.
- Virt
Queue VirtIOqueue implementation.
Constants
- VIRTIO_
F_ EVENT_ IDX - VirtIO feature bit for event index-based notification suppression (VirtIO spec 2.7.7).